transcript_lines

Function transcript_lines 

pub fn transcript_lines(
    messages: &[MemMessage],
    width: usize,
) -> Vec<TranscriptLine>
Wrap a chat transcript into width-bounded TranscriptLines ready to draw into a width-column pane, using the default TranscriptStyle.

width is the inner width of the target Rect (columns available for text). A width of 0 is treated as 1 to avoid an infinite wrap. Hard newlines in message content start new lines; over-long lines are wrapped at the width boundary (word-aware when a space is available).