pub fn evaluate(node: &Subtask, tree: &Plan, facts: &Facts<'_>) -> NodeVerdictExpand description
Gather facts for node and apply its completion rule.
pub fn evaluate(node: &Subtask, tree: &Plan, facts: &Facts<'_>) -> NodeVerdictGather facts for node and apply its completion rule.