pub struct CommunityTunings {
pub format: FormatMeta,
pub profiles: Vec<TuningProfile>,
}Expand description
Top-level community tunings document.
Fields
format: FormatMetaprofiles: Vec<TuningProfile>Model tuning profiles.
Implementations
Sourceimpl CommunityTunings
Find a profile for the given model name (exact match).
impl CommunityTunings
Find a profile for the given model name (exact match).